"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var models_1 = require("./models");
var colors_1 = require("colors");
var logFormat = {
    delimiter: '\t',
    format: '%l%s[%d %t]%s%v'
};
colors_1.setTheme({
    debug: ['black', 'bold'],
    info: ['white', 'bold', 'bgBlue'],
    ok: ['white', 'bold', 'bgGreen'],
    warn: ['white', 'bold', 'bgYellow'],
    error: ['white', 'bold', 'bgRed'],
    panic: ['white', 'bold', 'bgRed', 'inverse']
});
function format(settings, type, values) {
    var _a = settings.format ? settings.format : logFormat, delimiter = _a.delimiter, format = _a.format;
    var now = new Date();
    // %s
    var retString = format.replace(/\%s/g, delimiter);
    // %d
    retString = retString.replace(/\%d/g, now.toLocaleDateString());
    // %t
    retString = retString.replace(/\%t/g, now.toLocaleTimeString());
    // %l
    retString = retString.replace(/\%l/g, (function () {
        switch (type) {
            case models_1.LogLevel.info:
                if (settings.useColors) {
                    // @ts-ignore
                    return '[INFO]'.info;
                }
                else {
                    return '[INFO]';
                }
                break;
            case models_1.LogLevel.ok:
                if (settings.useColors) {
                    // @ts-ignore
                    return '[OK]'.ok;
                }
                else {
                    return '[OK]';
                }
                break;
            case models_1.LogLevel.warn:
                if (settings.useColors) {
                    // @ts-ignore
                    return '[WARN]'.warn;
                }
                else {
                    return '[WARN]';
                }
                break;
            case models_1.LogLevel.error:
                if (settings.useColors) {
                    // @ts-ignore
                    return '[ERROR]'.error;
                }
                else {
                    return '[ERROR]';
                }
                break;
            case models_1.LogLevel.panic:
                if (settings.useColors) {
                    // @ts-ignore
                    return '[PANIC]'.panic;
                }
                else {
                    return '[PANIC]';
                }
                break;
            default:
                if (settings.useColors) {
                    // @ts-ignore
                    return '[DEBUG]'.debug;
                }
                else {
                    return '[DEBUG]';
                }
                break;
        }
    })());
    // %v
    retString = retString.replace(/\%v/g, (function () {
        var data = [];
        for (var _i = 0, values_1 = values; _i < values_1.length; _i++) {
            var v = values_1[_i];
            if (typeof v !== 'object') {
                data.push(v);
            }
            else {
                data.push("" + JSON.stringify(v));
            }
        }
        return data.join(delimiter);
    })());
    return retString;
}
exports.format = format;
