"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var process = __importStar(require("process"));
var path = __importStar(require("path"));
var fs = __importStar(require("fs"));
var models_1 = require("./models");
var format_1 = require("./format");
var FileLogger = /** @class */ (function () {
    function FileLogger(_logLevel, options) {
        if (_logLevel === void 0) { _logLevel = models_1.LogLevel.warn; }
        if (options === void 0) { options = {}; }
        this._logLevel = _logLevel;
        this.options = options;
        this.settings = {
            level: _logLevel,
            format: options.format ? options.format : null,
            useColors: false,
            path: options.path ? options.path : path.join(process.cwd(), path.basename(process.cwd()) + ".log")
        };
        this.stream = fs.createWriteStream(this.settings.path, {
            encoding: 'utf8',
            flags: 'a'
        });
    }
    FileLogger.prototype.debug = function (v) {
        if (this._logLevel <= models_1.LogLevel.debug) {
            var data = format_1.format(this.settings, models_1.LogLevel.debug, v);
            // console.log(data);
            this.stream.write(data + '\n');
        }
    };
    FileLogger.prototype.info = function (v) {
        if (this._logLevel <= models_1.LogLevel.info) {
            var data = format_1.format(this.settings, models_1.LogLevel.info, v);
            // console.log(data);
            this.stream.write(data + '\n');
        }
    };
    FileLogger.prototype.ok = function (v) {
        if (this._logLevel <= models_1.LogLevel.ok) {
            var data = format_1.format(this.settings, models_1.LogLevel.ok, v);
            // console.log(data);
            this.stream.write(data + '\n');
        }
    };
    FileLogger.prototype.warn = function (v) {
        if (this._logLevel <= models_1.LogLevel.warn) {
            var data = format_1.format(this.settings, models_1.LogLevel.warn, v);
            // console.log(data);
            this.stream.write(data + '\n');
        }
    };
    FileLogger.prototype.error = function (v) {
        if (this._logLevel <= models_1.LogLevel.error) {
            var data = format_1.format(this.settings, models_1.LogLevel.error, v);
            // console.log(data);
            this.stream.write(data + '\n');
        }
    };
    FileLogger.prototype.panic = function (v) {
        if (this._logLevel <= models_1.LogLevel.panic) {
            var data = format_1.format(this.settings, models_1.LogLevel.panic, v);
            // console.log(data);
            this.stream.write(data + '\n');
        }
    };
    FileLogger.prototype.close = function () {
        this.stream.end();
    };
    return FileLogger;
}());
exports.FileLogger = FileLogger;
